# a História de n Quadrados
    
    About n [Squares]

projeto de pesquisa/software de TCC sobre este Pacote de Exploração de Algoritmos Genéticos e Arte baseado em obras, ideias e métodos gráficos bidimensionais do Construtivismo Russo;